@@ -142,9 +142,11 @@ sub profiles
 	return qw(http://purl.org/uF/adr/0.9/
 		http://microformats.org/profile/hcard
 		http://ufs.cc/x/hcard
+		http://microformats.org/profile/specs
+		http://ufs.cc/x/specs
 		http://www.w3.org/2006/03/hcard
 		http://purl.org/uF/hCard/1.0/
-		http://purl.org/uF/2008/03/ );
+		http://purl.org/uF/2008/03/);
 }
 
 1;
